"""Custom exceptions for the RSS scraper."""


class ScrapingError(Exception):
    """Base exception for scraping-related errors."""
    pass


class ValidationError(ScrapingError):
    """Exception raised for validation errors."""
    pass


class NetworkError(ScrapingError):
    """Exception raised for network-related errors."""
    pass


class PageLoadError(NetworkError):
    """Exception raised when page fails to load properly."""
    pass


class ContentSizeError(ScrapingError):
    """Exception raised when content exceeds size limits."""
    pass


class ParseError(ScrapingError):
    """Exception raised when HTML parsing fails."""
    pass


class ConfigurationError(ScrapingError):
    """Exception raised for configuration-related errors."""
    pass


class FileOperationError(ScrapingError):
    """Exception raised for file operation errors."""
    pass